@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h 3397 2012-09-30 02:26:07Z mdootson $
+// RCS-ID:      $Id: helpers.h 3499 2013-05-02 01:46:04Z mdootson $
 // Copyright:   (c) 2000-2011 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -69,18 +69,14 @@ inline SV* wxPli_wxString_2_sv( pTHX_ const wxString& str, SV* out )
 }
 
 #define WXCHAR_INPUT( var, type, arg ) \
-  const wxWCharBuffer var##_tmp = ( SvUTF8( arg ) ) ? \
-            ( wxString( SvPVutf8_nolen( arg ), wxConvUTF8 ) ).wc_str() \
-          : ( wxString( SvPV_nolen( arg ), wxConvLibc ) ).wc_str(); \
+  const wxWCharBuffer var##_tmp = ( wxString( SvPVutf8_nolen( arg ), wxConvUTF8 ) ).wc_str(); \
   var = const_cast<type>( var##_tmp.data() );
 
 #define WXCHAR_OUTPUT( var, arg ) \
   wxPli_wxChar_2_sv( aTHX_ var, arg )
 
 #define WXSTRING_INPUT( var, type, arg ) \
-  var =  ( SvUTF8( arg ) ) ? \
-           wxString( SvPVutf8_nolen( arg ), wxConvUTF8 ) \
-         : wxString( SvPV_nolen( arg ), wxConvLibc );
+  var = wxString( SvPVutf8_nolen( arg ), wxConvUTF8 );
 
 #define WXSTRING_OUTPUT( var, arg ) \
   wxPli_wxString_2_sv( aTHX_ var, arg )
@@ -104,18 +100,14 @@ inline SV* wxPli_wxString_2_sv( pTHX_ const wxString& str, SV* out )
 }
 
 #define WXCHAR_INPUT( var, type, arg ) \
-  const wxString var##_tmp = ( SvUTF8( arg ) ) ? \
-            ( wxString( SvPVutf8_nolen( arg ), wxConvUTF8 ) ) \
-          : ( wxString( SvPV_nolen( arg ), wxConvLibc ) ); \
+  const wxString var##_tmp = ( wxString( SvPVutf8_nolen( arg ), wxConvUTF8 ) ); \
   var = const_cast<type>( static_cast<const type>( var##_tmp.wc_str() ) );
 
 #define WXCHAR_OUTPUT( var, arg ) \
   wxPli_wxChar_2_sv( aTHX_ var, arg )
 
 #define WXSTRING_INPUT( var, type, arg ) \
-  var =  ( SvUTF8( arg ) ) ? \
-           wxString( SvPVutf8_nolen( arg ), wxConvUTF8 ) \
-         : wxString( SvPV_nolen( arg ), wxConvLibc );
+  var =  wxString( SvPVutf8_nolen( arg ), wxConvUTF8 );
 
 #define WXSTRING_OUTPUT( var, arg ) \
   wxPli_wxString_2_sv( aTHX_ var, arg )
