@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     07/09/2001
-// RCS-ID:      $Id: tipprovider.h 2057 2007-06-18 23:03:00Z mbarbon $
-// Copyright:   (c) 2001-2002 Mattia Barbon
+// RCS-ID:      $Id: tipprovider.h 2239 2007-10-07 19:16:59Z mbarbon $
+// Copyright:   (c) 2001-2002, 2007 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -28,9 +28,11 @@ public:
     void SetCurrentTip( size_t currentTip ) { m_currentTip = currentTip; }
 
     DEC_V_CBACK_WXSTRING__VOID( GetTip );
+    DEC_V_CBACK_WXSTRING__WXSTRING( PreprocessTip );
 };
 
 DEF_V_CBACK_WXSTRING__VOID_pure( wxPliTipProvider, wxTipProvider, GetTip );
+DEF_V_CBACK_WXSTRING__WXSTRING( wxPliTipProvider, wxTipProvider, PreprocessTip );
 
 // Local variables: //
 // mode: c++ //
